pub enum CompatSsoLoginState {
Pending,
Fulfilled {
fulfilled_at: DateTime<Utc>,
browser_session_id: Ulid,
},
Exchanged {
fulfilled_at: DateTime<Utc>,
exchanged_at: DateTime<Utc>,
compat_session_id: Ulid,
},
}Variants
Implementations
Sourceimpl CompatSsoLoginState
impl CompatSsoLoginState
Sourcepub fn is_pending(&self) -> bool
pub fn is_pending(&self) -> bool
Returns true if the compat SSO login state is Pending.
Sourcepub fn is_fulfilled(&self) -> bool
pub fn is_fulfilled(&self) -> bool
Returns true if the compat SSO login state is Fulfilled.
Sourcepub fn is_exchanged(&self) -> bool
pub fn is_exchanged(&self) -> bool
Returns true if the compat SSO login state is Exchanged.
Sourcepub fn fulfilled_at(&self) -> Option<DateTime<Utc>>
pub fn fulfilled_at(&self) -> Option<DateTime<Utc>>
Get the time at which the login was fulfilled.
Returns None if the compat SSO login state is Pending.
Sourcepub fn exchanged_at(&self) -> Option<DateTime<Utc>>
pub fn exchanged_at(&self) -> Option<DateTime<Utc>>
Get the time at which the login was exchanged.
Returns None if the compat SSO login state is not Exchanged.
Sourcepub fn session_id(&self) -> Option<Ulid>
pub fn session_id(&self) -> Option<Ulid>
Sourcepub fn fulfill(
self,
fulfilled_at: DateTime<Utc>,
browser_session: &BrowserSession,
) -> Result<Self, InvalidTransitionError>
pub fn fulfill( self, fulfilled_at: DateTime<Utc>, browser_session: &BrowserSession, ) -> Result<Self, InvalidTransitionError>