pub enum AuthorizationGrantStage {
Pending,
Fulfilled {
session_id: Ulid,
fulfilled_at: DateTime<Utc>,
},
Exchanged {
session_id: Ulid,
fulfilled_at: DateTime<Utc>,
exchanged_at: DateTime<Utc>,
},
Cancelled {
cancelled_at: DateTime<Utc>,
},
}Variants
Implementations
Sourceimpl AuthorizationGrantStage
impl AuthorizationGrantStage
pub fn new() -> Self
Sourcepub fn is_pending(&self) -> bool
pub fn is_pending(&self) -> bool
Returns true if the authorization grant stage is Pending.
Sourcepub fn is_fulfilled(&self) -> bool
pub fn is_fulfilled(&self) -> bool
Returns true if the authorization grant stage is Fulfilled.
Sourcepub fn is_exchanged(&self) -> bool
pub fn is_exchanged(&self) -> bool
Returns true if the authorization grant stage is Exchanged.