pub struct Client {Show 18 fields
pub id: Ulid,
pub client_id: String,
pub metadata_digest: Option<String>,
pub encrypted_client_secret: Option<String>,
pub application_type: Option<ApplicationType>,
pub redirect_uris: Vec<Url>,
pub grant_types: Vec<GrantType>,
pub client_name: Option<String>,
pub logo_uri: Option<Url>,
pub client_uri: Option<Url>,
pub policy_uri: Option<Url>,
pub tos_uri: Option<Url>,
pub jwks: Option<JwksOrJwksUri>,
pub id_token_signed_response_alg: Option<JsonWebSignatureAlg>,
pub userinfo_signed_response_alg: Option<JsonWebSignatureAlg>,
pub token_endpoint_auth_method: Option<OAuthClientAuthenticationMethod>,
pub token_endpoint_auth_signing_alg: Option<JsonWebSignatureAlg>,
pub initiate_login_uri: Option<Url>,
}Fields
id: Ulidclient_id: StringClient identifier
metadata_digest: Option<String>Hash of the client metadata
encrypted_client_secret: Option<String>application_type: Option<ApplicationType>redirect_uris: Vec<Url>Array of Redirection URI values used by the Client
grant_types: Vec<GrantType>Array containing a list of the OAuth 2.0 Grant Types that the Client is declaring that it will restrict itself to using.
client_name: Option<String>Name of the Client to be presented to the End-User
logo_uri: Option<Url>URL that references a logo for the Client application
client_uri: Option<Url>URL of the home page of the Client
policy_uri: Option<Url>URL that the Relying Party Client provides to the End-User to read about the how the profile data will be used
tos_uri: Option<Url>URL that the Relying Party Client provides to the End-User to read about the Relying Party’s terms of service
jwks: Option<JwksOrJwksUri>id_token_signed_response_alg: Option<JsonWebSignatureAlg>JWS alg algorithm REQUIRED for signing the ID Token issued to this Client
userinfo_signed_response_alg: Option<JsonWebSignatureAlg>JWS alg algorithm REQUIRED for signing UserInfo Responses.
token_endpoint_auth_method: Option<OAuthClientAuthenticationMethod>Requested authentication method for the token endpoint
token_endpoint_auth_signing_alg: Option<JsonWebSignatureAlg>JWS alg algorithm that MUST be used for signing the JWT used to
authenticate the Client at the Token Endpoint for the private_key_jwt
and client_secret_jwt authentication methods
initiate_login_uri: Option<Url>URI using the https scheme that a third party can use to initiate a login by the RP
Implementations
Sourceimpl Client
impl Client
Sourcepub fn resolve_redirect_uri<'a>(
&'a self,
redirect_uri: &'a Option<Url>,
) -> Result<&'a Url, InvalidRedirectUriError>
pub fn resolve_redirect_uri<'a>( &'a self, redirect_uri: &'a Option<Url>, ) -> Result<&'a Url, InvalidRedirectUriError>
Determine which redirect URI to use for the given request.
Errors
Returns an error if:
- no URL was given but multiple redirect URIs are registered,
- no URL was registered, or
- the given URL is not registered
Sourcepub fn into_metadata(self) -> ClientMetadata
pub fn into_metadata(self) -> ClientMetadata
Create a client metadata object for this client