pub struct PersonalSession {
pub id: Ulid,
pub state: SessionState,
pub owner: PersonalSessionOwner,
pub actor_user_id: Ulid,
pub human_name: String,
pub scope: Scope,
pub created_at: DateTime<Utc>,
pub last_active_at: Option<DateTime<Utc>>,
pub last_active_ip: Option<IpAddr>,
}Fields
id: Ulidstate: SessionStateowner: PersonalSessionOwneractor_user_id: Ulidhuman_name: Stringscope: ScopeThe scope for the session, identical to OAuth 2 sessions. May or may not include a device scope (personal sessions can be deviceless).
created_at: DateTime<Utc>last_active_at: Option<DateTime<Utc>>last_active_ip: Option<IpAddr>Implementations
Sourceimpl PersonalSession
impl PersonalSession
Sourcepub fn has_device(&self) -> bool
pub fn has_device(&self) -> bool
Returns whether the scope of this session contains a device scope; in other words: whether this session has a device.
Methods from Deref<Target = SessionState>
Sourcepub fn is_revoked(&self) -> bool
pub fn is_revoked(&self) -> bool
Returns true if the session state is Revoked.